]> git.mxchange.org Git - friendica.git/blobdiff - index.php
Add pwdreset_time field to user table
[friendica.git] / index.php
index c4ccc9ef24db8bda5837516c3f1a89987cfd2275..ad65a701ac0b8547b2b79b02248818a71695df1b 100644 (file)
--- a/index.php
+++ b/index.php
@@ -13,6 +13,7 @@ use Friendica\BaseObject;
 use Friendica\Content\Nav;
 use Friendica\Core\Addon;
 use Friendica\Core\System;
+use Friendica\Core\Theme;
 use Friendica\Core\Config;
 use Friendica\Core\Worker;
 use Friendica\Database\DBM;
@@ -179,7 +180,7 @@ if (! x($_SESSION, 'last_updated')) {
 /*
  * check_config() is responsible for running update scripts. These automatically
  * update the DB schema whenever we push a new one out. It also checks to see if
* any plugins have been added or removed and reacts accordingly.
  */
 
 // in install mode, any url loads install module
@@ -191,7 +192,7 @@ if ($install && $a->module!="view") {
 } else {
        check_url($a);
        check_db(false);
-       check_plugins($a);
+       check_addons($a);
 }
 
 Nav::setSelected('nothing');
@@ -227,7 +228,7 @@ if (strlen($a->module)) {
 
        /**
         * We will always have a module name.
-        * First see if we have a plugin which is masquerading as a module.
+        * First see if we have an addon which is masquerading as a module.
         */
 
        // Compatibility with the Android Diaspora client
@@ -242,7 +243,7 @@ if (strlen($a->module)) {
 
        $privateapps = Config::get('config', 'private_addons');
 
-       if (is_array($a->plugins) && in_array($a->module, $a->plugins) && file_exists("addon/{$a->module}/{$a->module}.php")) {
+       if (is_array($a->addons) && in_array($a->module, $a->addons) && file_exists("addon/{$a->module}/{$a->module}.php")) {
                //Check if module is an app and if public access to apps is allowed or not
                if ((!local_user()) && Addon::isApp($a->module) && $privateapps === "1") {
                        info(t("You must be logged in to use addons. "));
@@ -517,15 +518,15 @@ header('X-Frame-Options: sameorigin');
  * The page templates are located in /view/php/ or in the theme directory.
  */
 if (isset($_GET["mode"])) {
-       $template = theme_include($_GET["mode"] . '.php');
+       $template = Theme::getPathForFile($_GET["mode"] . '.php');
 }
 
 // If there is no page template use the default page template
 if (empty($template)) {
-       $template = theme_include("default.php");
+       $template = Theme::getPathForFile("default.php");
 }
 
/// @TODO Looks unsafe (remote-inclusion), is maybe not but theme_include() uses file_exists() but does not escape anything
 require_once $template;
 
 killme();
@@ -179,7 +180,7 @@ if (! x($_SESSION, 'last_updated')) {
  * check_config() is responsible for running update scripts. These automatically
  * update the DB schema whenever we push a new one out. It also checks to see if
- * any plugins have been added or removed and reacts accordingly.
+ * any addons have been added or removed and reacts accordingly.
  */
 
@@ -517,15 +518,15 @@ header('X-Frame-Options: sameorigin');
 }
 
-/// @TODO Looks unsafe (remote-inclusion), is maybe not but theme_include() uses file_exists() but does not escape anything
+/// @TODO Looks unsafe (remote-inclusion), is maybe not but Theme::getPathForFile() uses file_exists() but does not escape anything
 require_once $template;
 